@@ -387,6 +387,10 @@ def add_cronjob_task(_add_value, func=None):
 
 
 def add_task(_add_value, func=None):
+    _add_value = get_table(_add_value, Task)
+    if 'status' in _add_value.__table__.columns:
+        if _add_value.status is None:
+            _add_value.status = 'new'
     return add_new_record(_add_value, Task, func=func)
 
 
@@ -422,7 +426,7 @@ def get_new_task(worker=None):
         return error
 
     # 1. status is null and scheduled_time <= NOW()
-    filter_value = and_(Task.status.is_(None),
+    filter_value = and_(Task.status == 'new',
                         Task.scheduled_time.isnot(None),
                         Task.scheduled_time <= datetime.datetime.now())
     if project:
@@ -441,7 +445,7 @@ def get_new_task(worker=None):
 
     if task is None:
         # 3. Simple Tasks
-        filter_value = and_(Task.status.is_(None), Task.scheduled_time.is_(None))
+        filter_value = and_(Task.status == 'new', Task.scheduled_time.is_(None))
         if project:
             filter_value = and_(filter_value, Task.project == project)
         task = session.query(Task).with_for_update(skip_locked=True).filter(filter_value).order_by(
@@ -513,12 +517,12 @@ def get_new_tasks(task_limit, worker=None):
         return error
 
     # 1. status is null and scheduled_time <= NOW()
-    filter_value_1 = and_(Task.status.is_(None),
+    filter_value_1 = and_(Task.status == 'new',
                           Task.scheduled_time.isnot(None),
                           Task.scheduled_time <= datetime.datetime.now())
 
     # 2. status = 'error' max_retry_count > retry_count
-    filter_value_2 = and_(Task.status == 'error',
+    filter_value_2 = and_(Task.status == 'new',
                           or_(Task.retry_count.is_(None), Task.max_retry_count > Task.retry_count))
 
     # 3. Simple Tasks
